pub struct Basic {
pub msg: String,
pub span: Span,
}👎Deprecated: This is a nonspecific error constructor that should eventually become a prebuilt message.
An explicit error message with its span. This error construct is meant to be phased out in favor of a prebuilt error message.
Fields
msg: String👎Deprecated: This is a nonspecific error constructor that should eventually become a prebuilt message.
Error kind.
span: Span👎Deprecated: This is a nonspecific error constructor that should eventually become a prebuilt message.
Error location.