ClkTooSlowExpectImplicit

Struct ClkTooSlowExpectImplicit 

pub struct ClkTooSlowExpectImplicit<slow, implicit, extra> {
    pub slow: slow,
    pub implicit: implicit,
    pub extra: extra,
}
Generate an error when due to implicit that has the implicit clock, slow was expected to also have the implicit clock but doesn’t.

Fields

slow: slow

Clocked by something else, should have been 'self.

implicit: implicit

Clocked by 'self

extra: extra

Extra help messages, optionally.