CmpNotAssociative

Struct CmpNotAssociative 

pub struct CmpNotAssociative<oper1, first, site, second, third, oper2> {
    pub oper1: oper1,
    pub first: first,
    pub site: site,
    pub second: second,
    pub third: third,
    pub oper2: oper2,
}
Error for when a comparison operator is used with associativity. Since a = b = c is ambiguous (does it mean (a = b) = c or a = (b = c) or (a = b) and (b = c), we choose to reject all interpretations and ask for explicit parentheses around comparison operators.

Fields

oper1: oper1

The < of a < b > c

first: first

The a of a < b > c

site: site

The whole location of a < b > c

second: second

The b of a < b > c

third: third

The c of a < b > c

oper2: oper2

The > of a < b > c