UnusedGeneric

Struct UnusedGeneric 

pub struct UnusedGeneric<unused, inputs> {
    pub unused: unused,
    pub inputs: inputs,
}
When a generic type variable is unused and thus not inferrable

Fields

unused: unused

Type variable that is absent from the inputs declaration.

inputs: inputs

Declaration of said inputs.