Struct chandeliers_err::Acc

source ·
pub struct Acc { /* private fields */ }
Error accumulator to be able to

  • emit several fatal errors at once
  • emit warnings

Implementations

source

impl Acc

source

pub fn new() -> Self

Create an empty accumulator with no errors and no warnings.

source

pub fn error<T, E: IntoError>(&mut self, e: E) -> Result<T>

Push a fatal error to the accumulator.

Errors

Infaillible. Returns a Result so that you can do acc.error(...)?;

source

pub fn warning<E: IntoError>(&mut self, e: E)

Push a warning to the accumulator.

source

pub fn is_fatal(&self) -> bool

Determine if there were any errors inserted.

source

pub fn fetch(self) -> (Vec<Error>, Vec<Error>)

Extract the errors and warnings to be emitted.

source

pub fn scope(&mut self) -> AccScope<'_>

Create a new scope to record the success of intermediate computation.