pub struct AccScope<'a> { /* private fields */ }
Error scope to fail if one of several computations failed.

Usage example:

for e in &es {
    foo(acc, e)?;
}

will only try to execute foo until it reaches the first error. Subsequent elements will not be handled.

If instead we wish to execute them all we can do

Implementations

source

impl<'a> AccScope<'a>

source

pub fn compute<F>(&mut self, f: F)where F: FnOnce(&mut Acc) -> Result<()>,

Record the success of a new computation.

source

pub fn close(self) -> Result<()>

Consume the scope and emit an error if and only if one of the recorded computations failed.

source

pub fn error<E: IntoError>(&mut self, e: E)

Apply an error to the inner accumulator.

source

pub fn warning<E: IntoError>(&mut self, e: E)

Apply a warning to the inner accumulator.