pub struct CmpNotAssociative<First, Oper1, Second, Oper2, Third, Site> {
    pub oper1: Oper1,
    pub first: First,
    pub site: Site,
    pub second: Second,
    pub third: Third,
    pub oper2: Oper2,
}
Error for when a comparison operator is used with associativity.

Since a = b = c is ambiguous (does it mean (a = b) = c or a = (b = c) or (a = b) and (b = c), we choose to reject all interpretations and ask for explicit parentheses around comparison operators.

Fields

oper1: Oper1

The < of a < b > c

first: First

The a of a < b > c

site: Site

The whole location of a < b > c

second: Second

The b of a < b > c

third: Third

The c of a < b > c

oper2: Oper2

The > of a < b > c