EAccum

Struct EAccum 

pub struct EAccum { /* private fields */ }
Error accumulator to be able to

  • emit several fatal errors at once
  • emit warnings

Implementations

Source

impl EAccum

pub fn error<T, E: IntoError>(&mut self, e: E) -> Option<T>

Push a fatal error to the accumulator. Always returns a None so that you can use the construct acc.error(...)?;

pub fn warning<E: IntoError>(&mut self, e: E)

Push a warning to the accumulator.

pub fn is_fatal(&self) -> bool

Determine if there were any errors inserted.

pub fn fetch(self) -> (Vec<Error>, Vec<Error>)

Extract the errors and warnings to be emitted.

pub fn scope(&mut self) -> EAccumScope<'_>

Create a new scope to record the success of intermediate computation.