pub type Span = Transparent<Span>;Expand description
Reexport of Span, but this time forgeable in tests and
transparent to Eq and Hash.
Aliased Type
pub struct Span { /* private fields */ }Trait Implementations
Sourceimpl TryDefSite for Span
impl TryDefSite for Span
Sourcefn try_def_site(&self) -> Option<Span>
fn try_def_site(&self) -> Option<Span>
Try to get a span from the object (by default we don’t get any,
but a wrapper might provide one)