Structs
- Basic
Deprecated - An explicit error message with its span. This error construct is meant to be phased out in favor of a prebuilt error message.
- Binop
Mismatch - Generate an error for a binary operator that expected arguments of a specific type.
- Bool
Required - Generate an error for something that should have been a bool but isn’t,
e.g.
if 1 then 0 else 1. - ClkNot
Comparable - When two clocks are both non-implicit but different.
- ClkNot
Identical - When two clocks should have been identical.
- ClkToo
Slow Expect Implicit - Generate an error when due to
implicitthat has the implicit clock,slowwas expected to also have the implicit clock but doesn’t. - CmpNot
Associative - Error for when a comparison operator is used with associativity.
Since
a = b = cis ambiguous (does it mean(a = b) = cora = (b = c)or(a = b) and (b = c), we choose to reject all interpretations and ask for explicit parentheses around comparison operators. - Cycle
- Generate an error for a cyclic definition.
- Display
TrySpan - Generic wraper that implements
DisplayandTrySpanto wrap together items that don’t implement both. - Executable
Node Sig - Node is declared as executable, but has nonempty inputs or outputs.
- FunNot
Found - Generate an error for an undeclared function.
- Graph
Unit Decl Twice - Error message for an object that was defined twice when only one declaration should exist.
- Graph
Unit Depends OnItself - Special case of Cycle: custom message for an object that depends specifically on itself directly.
- Graph
Unit Undeclared - Error for an object that should have been declared but was not.
- Inapplicable
Attribute - Attribute cannot apply to this language construct.
- NotA
Clock - When an expression is not a valid clock (anything but a local variable).
- NotConst
- Generate an erorr for an expression that is noot valid in a
constdeclaration. - NotPositive
- Error for when one tried to access too far into the past.
- Raw
- An explicit sequence of errors and spans This error construct is meant to be phased out in favor of a prebuilt error message.
- Scalar
NotTuple - Two types cannot be equal because one is a tuple and the other a scalar
- Shallow
Pre - Attempted to use a
prein register mode without any depth available - Suggest
- Wrapper to display suggestions.
- TyVar
NotFound - Generate an error for a type variable that was not declared yet, which has consequences on what we should say is and isn’t available.
- Type
Mismatch - Generate an error for incompatible types between a “left” and a “right” values.
- Undeclared
Generic - When a generic type variable is unused and thus not inferrable.
- Unhandled
LitType - Error for a literal that is not supported.
Lustre only has
float,int, andboolliterals, so e.g. a&strwill trigger this error. - Unop
Mismatch - Generate an error for a unary operator that expected an argument of a specific type.
- Unsat
Generic Constraint - Impossible to satisfy generic constraints introduced by bounds.
- Unused
Generic - When a generic type variable is unused and thus not inferrable
- VarNot
Found - Generate an error for a variable that was not declared yet.
Traits
- Into
Error - Generate an
Error. - TryDef
Site - Objects that have a different way that they can be seen as a span
- TrySpan
- Objects that can be converted to spans.