TyVarNotFound

Struct TyVarNotFound 

pub struct TyVarNotFound<var, suggest> {
    pub var: var,
    pub suggest: suggest,
}
Generate an error for a type variable that was not declared yet, which has consequences on what we should say is and isn’t available.

Fields

var: var

What is missing.

suggest: suggest

Local variable suggestions.