pub struct UnusedGeneric<unused, inputs> {
pub unused: unused,
pub inputs: inputs,
}Expand description
When a generic type variable is unused and thus not inferrable
Fields
unused: unusedType variable that is absent from the inputs declaration.
inputs: inputsDeclaration of said inputs.