pub struct EAccumScope<'a> { /* private fields */ }Expand description
Error scope to fail if one of several computations failed.
Usage example:
for e in &es {
foo(acc, e)?;
}will only try to execute foo until it reaches the first error.
Subsequent elements will not be handled.
If instead we wish to execute them all we can do
Implementations