pub struct Transparent<T> { /* private fields */ }
A type that transparently implements PartialEq and Hash, to be used in structs that carry additional data that should not be relevant in comparisons.

It additionally supports creating dummy values and they will also compare equal to all other and hash identically.

Implementations

source

impl<T> Transparent<T>

source

pub fn unwrap(self) -> T

Assert that the value was not forged and get its contents.

Panics

fails if self was obtainedy by Transparent::forge().

source

pub fn forge() -> Self

Create a dummy value.

source

impl<T> Transparent<T>

source

pub fn from(inner: T) -> Self

Wrap in a transparent.

source

impl Transparent<Span>

source

pub fn join(self, other: Self) -> Option<Self>

Map join to the inner spans