Struct chandeliers_err::transparent::Transparent
source · pub struct Transparent<T> { /* private fields */ }Expand description
A type that transparently implements PartialEq and Hash, to be used
in structs that carry additional data that should not be relevant in comparisons.
It additionally supports creating dummy values and they will also compare equal to all other and hash identically.
Implementations
sourceimpl<T> Transparent<T>
impl<T> Transparent<T>
sourceimpl<T> Transparent<T>
impl<T> Transparent<T>